pub enum ShareError {
InvalidCiphertext(Idx, EciesError),
InvalidShare(Idx),
InvalidPublicPolynomial(Idx, usize, usize),
}Expand description
Error which may occur while processing a share in Phase 1
Variants
InvalidCiphertext(Idx, EciesError)
InvalidCipherText returns the error raised when decrypting the encrypted share.
InvalidShare is raised when the share does not corresponds to the public polynomial associated.
InvalidPublicPolynomial(Idx, usize, usize)
InvalidPublicPolynomial is raised when the public polynomial does not
have the correct degree. Each public polynomial in the scheme must have
a degree equals to threshold - 1 set for the DKG protocol.
The two fields are (1) the degree of the polynomial and (2) the
second is the degree it should be,i.e. threshold - 1.